@@ -3,12 +3,107 @@ from selectorlib import Extractor
 import requests
 import random
 
+YAML_STRING = """
+categories:
+    css: 'div.a-subheader ul.a-unordered-list'
+    xpath: null
+    type: Text
+title:
+    css: 'h1.a-size-large span.a-size-large'
+    xpath: null
+    type: Text
+selling_price1:
+    css: 'td.a-span12 span.a-price.a-size-medium span:nth-of-type(2)'
+    xpath: null
+    type: Text
+mrp1:
+    css: 'td.a-span12.a-color-secondary span.a-price span:nth-of-type(2)'
+    xpath: null
+    type: Text
+description:
+    css: 'div.a-section.a-spacing-medium span.a-list-item'
+    xpath: null
+    multiple: true
+    type: Text
+attribute_keys1:
+    css: 'td.a-span3 span.a-size-base'
+    xpath: null
+    multiple: true
+    type: Text
+attribute_values1:
+    css: 'td.a-span9 span.a-size-base'
+    xpath: null
+    multiple: true
+    type: Text
+rating1:
+    css: 'div.centerColAlign span.reviewCountTextLinkedHistogram a.a-popover-trigger'
+    xpath: null
+    type: Text
+mrp2:
+    css: 'span.a-size-small span.a-price span:nth-of-type(2)'
+    xpath: null
+    type: Text
+selling_price2:
+    css: 'div.centerColAlign span.a-price-whole'
+    xpath: null
+    type: Text
+attribute_keys2:
+    css: 'div.a-expander-content table.a-keyvalue th.a-color-secondary'
+    xpath: null
+    multiple: true
+    type: Text
+attribute_values2:
+    css: 'div.a-expander-content td.a-size-base'
+    xpath: null
+    multiple: true
+    type: Text
+rating2:
+    css: 'div.a-section div.celwidget span.reviewCountTextLinkedHistogram a.a-popover-trigger'
+    xpath: null
+    type: Text
+ranks1:
+    css: 'div.a-section.feature > ul.a-unordered-list:nth-of-type(1) > li > span.a-list-item'
+    xpath: null
+    type: Text
+ranks2:
+    css: 'div.a-section div.a-section tr:nth-of-type(3) td'
+    xpath: null
+    type: Text
+number_of_ratings:
+    css: 'div.centerColAlign span.a-declarative span.a-size-base'
+    xpath: null
+    type: Text
+store:
+    css: 'div#bylineInfo_feature_div.celwidget div.a-section'
+    xpath: null
+    type: Text
+product_details_keys1:
+    css: 'div.a-section.feature div span.a-text-bold'
+    xpath: null
+    multiple: true
+    type: Text
+product_details_values1:
+    css: 'div.a-section div span.a-list-item span:nth-of-type(2)'
+    xpath: null
+    multiple: true
+    type: Text
+product_details_keys2:
+    css: 'div.a-section div.a-section th.a-color-secondary'
+    xpath: null
+    multiple: true
+    type: Text
+product_details_values2:
+    css: 'div.a-section div.a-section td'
+    xpath: null
+    multiple: true
+    type: Text
+"""
 
 
 class ProductDetailsExtractor:
     def __init__(self):
-        self._amazon_product_extractor = Extractor.from_yaml_file(
-            'amazondata/amazon_product.yml')
+        self._amazon_product_extractor = Extractor.from_yaml_string(
+            YAML_STRING)
 
     def __scrape(self, url):
         headers = {
